@@ -167,11 +167,14 @@ else
     # Are knots supplied in a list?
     knl <- is.list( npar )
     if( knl ) nk <- sapply( npar, length )
-    MA <- if( knl ) ns( A  , knots=npar[["A"]][-c(1,nk[1])], Bo=npar[["A"]][c(1,nk[1])] )
+    MA <- if( knl ) ns( A  , knots=npar[["A"]][-c(1,nk[1])],
+                                Bo=npar[["A"]][c(1,nk[1])] )
                else ns( A  ,    df=npar[["A"]] )
-    MP <- if( knl ) ns( P  , knots=npar[["P"]][-c(1,nk[2])], Bo=npar[["P"]][c(1,nk[2])] )
+    MP <- if( knl ) ns( P  , knots=npar[["P"]][-c(1,nk[2])],
+                                Bo=npar[["P"]][c(1,nk[2])] )
                else ns( P  ,    df=npar[["P"]] )
-    MC <- if( knl ) ns( P-A, knots=npar[["C"]][-c(1,nk[3])], Bo=npar[["C"]][c(1,nk[3])] )
+    MC <- if( knl ) ns( P-A, knots=npar[["C"]][-c(1,nk[3])],
+                                Bo=npar[["C"]][c(1,nk[3])] )
                else ns( P-A,    df=npar[["C"]] )
     # The reference rows if required later
     Rp <- ns( p0, knots=attr( MP, "knots"), Boundary.knots=attr( MP, "Boundary.knots" ) )
@@ -192,15 +195,15 @@ else
     # Are knots supplied in a list?
     knl <- is.list( npar )
     if( knl ) nk <- sapply( npar, length )
-    MA <- if( knl ) bs( A, knots=npar["A"][-c(1,nk[1])],
-                           Bo=npar["A"][c(1,nk[1])], degree=deg )
-               else bs( A, df=npar["A"], degree=deg )
-    MP <- if( knl ) bs( P, knots=npar["P"][-c(1,nk[2])],
-                           Bo=npar["P"][c(1,nk[2])], degree=deg )
-               else bs( P, df=npar["P"], degree=deg )
-    MC <- if( knl ) bs( P-A, knots=npar["C"][-c(1,nk[3])],
-                             Bo=npar["C"][c(1,nk[3])], degree=deg )
-               else bs( P-A, df=npar["C"], degree=deg )
+    MA <- if( knl ) bs( A,   knots=npar[["A"]][-c(1,nk[1])],
+                                Bo=npar[["A"]][c(1,nk[1])], degree=deg )
+               else bs( A,      df=npar[["A"]], degree=deg )
+    MP <- if( knl ) bs( P,   knots=npar[["P"]][-c(1,nk[2])],
+                                Bo=npar[["P"]][c(1,nk[2])], degree=deg )
+               else bs( P,      df=npar[["P"]], degree=deg )
+    MC <- if( knl ) bs( P-A, knots=npar[["C"]][-c(1,nk[3])],
+                                Bo=npar[["C"]][c(1,nk[3])], degree=deg )
+               else bs( P-A,    df=npar[["C"]], degree=deg )
     # The reference rows if required later
     Rp <- bs( p0, knots=attr( MP, "knots"),
          Boundary.knots=attr( MP, "Boundary.knots" ),
